use crate::constants::database_tables_names::CLIENTS_TABLE;
use crate::data::api_client::APIClient;
use crate::data::error::ResultBoxError;
use crate::helpers::database::QueryInfo;

/// API helper
///
/// @author Pierre Hubert

/// Get information about a client
pub fn get_client(name: &str) -> ResultBoxError<APIClient> {
    QueryInfo::new(CLIENTS_TABLE)
        .cond("name", name)
        .query_row(|res| {
            Ok(APIClient {
                id: res.get_u64("id")?,
                name: res.get_str("name")?,
                domain: res.get_optional_str("domain")?,
                comment: res.get_optional_str("comment")?,
                default_expiration_time: res.get_u64("default_expiration_time")?,
            })
        })
}